@@ -93,13 +93,18 @@ def update_flash_cfg_data_do(chipname, chiptype, flash_id):
     return update_data_from_cfg(sub_module.bootheader_cfg_keys.bootheader_cfg_keys, cfg_dir + conf_name)
 
 
-def flash_bootheader_config_check(chipname, chiptype, flashid, file):
+def flash_bootheader_config_check(chipname, chiptype, flashid, file, parafile):
     magic_code = 0x504e4642
     flash_magic_code = 0x47464346
     offset, flashCfgLen, data, flashCrcOffset, crcOffset =\
         update_flash_cfg_data_do(chipname, chiptype, flashid)
 
-    fp = open(file, 'rb')
+    if parafile != "":
+        fp = open(os.path.join(app_path, parafile), 'wb')
+        fp.write(data)
+        fp.close()
+
+    fp = open(os.path.join(app_path, file), 'rb')
     rdata = bytearray(fp.read())
     fp.close()
     i = 0
@@ -126,13 +131,14 @@ def update_flash_cfg_data(chipname, chiptype, flash_id, cfg, bh_cfg_file, cfg_ke
     offset, flashCfgLen, data, flashCrcOffset, crcOffset = update_flash_cfg_data_do(chipname, chiptype, flash_id)
 
     para_file = cfg.get("FLASH_CFG", "flash_para")
-    fp = open(para_file, 'wb')
-    fp.write(data)
-    fp.close()
+    if para_file != "":
+        fp = open(os.path.join(app_path, para_file), 'wb')
+        fp.write(data)
+        fp.close()
 
     flash_file = re.compile('\s+').split(cfg.get("FLASH_CFG", "file"))
     for f in flash_file:
-        fp = open(f, 'rb')
+        fp = open(os.path.join(app_path, f), 'rb')
         rdata = bytearray(fp.read())
         fp.close()
         i = 0
